@@ -59,10 +59,6 @@ class PlanOptimizer:
                 roiObjectives = np.logical_or(roiObjectives, objective.maskVec)
         roiObjectives = np.logical_or(roiObjectives, roiRobustObjectives)
 
-        # reload beamlets and crop to optimization ROI
-        logger.info("Re-load and crop beamlets to optimization ROI...")
-        if self.plan.planDesign.beamlets is None:
-            self.plan.planDesign.beamlets.load()
         if use_MKL == 1:
             beamletMatrix = sparse_dot_mkl.dot_product_mkl(
                 sp.diags(roiObjectives.astype(np.float32), format='csc'), self.plan.planDesign.beamlets.toSparseMatrix())
@@ -73,7 +69,6 @@ class PlanOptimizer:
 
         if robust:
             for s in range(len(self.plan.planDesign.scenarios)):
-                self.plan.planDesign.scenarios[s].load()
                 if use_MKL == 1:
                     beamletMatrix = sparse_dot_mkl.dot_product_mkl(
                         sp.diags(roiRobustObjectives.astype(np.float32), format='csc'),
